#!/bin/env pwsh

param ($logsFromDays=10)

if ($IsLinux -and (-not $env:SUDO_UID))
{
    throw "this script must be run as root, aborting..."
}

$prefix = "netco_nms"
Write-Host "Generating events log package for ${prefix}:"
Write-Host

if ($IsLinux ){
  $logPath = (docker volume inspect --format '{{.Mountpoint}}' ${prefix}_satel_programdata)
  if ($logPath -eq "") {
    Write-Host
    Write-Host "Has NETCO STACKS been launched from this folder?"
    [Environment]::Exit(1)
  }
}
else {
    $logPath = "$PsScriptRoot/__lastEventslogs"
    If(!(test-path -PathType container $logPath)){
       New-Item -Path $logPath -ItemType Directory
    }
    else {
        Remove-Item $PsScriptRoot/__lastEventslogs/* -Recurse -Force
    }
	$liveviewContainerName = docker ps --filter name=netco_nms.liveview --format "{{.Names}}"
	Invoke-Expression "docker exec ${liveviewContainerName} sh -c 'rm -rf ./liveview0/events_log && mkdir ./liveview0/events_log && cp ./liveview0/logs/events*.csv* ./liveview0/events_log'"
    Invoke-Expression "docker cp ${liveviewContainerName}:/usr/share/Satel/NETCO/liveview0/events_log/. '$logPath'"
	Invoke-Expression "docker exec ${liveviewContainerName} sh -c 'rm -rf ./liveview0/events_log'"
}


Add-Type -A System.IO.Compression.FileSystem
$zipFileName = "$PsScriptRoot/netco_events_log_$(Get-Date -Format "yyyy-MM-dd_HHmmss").zip"
$zip = [System.IO.Compression.ZipFile]::Open($zipFileName, 'update')
$compressionLevel = [System.IO.Compression.CompressionLevel]::Optimal

Set-Location -Path $logPath
Get-ChildItem -Path . -Recurse -Include ('event*.csv*') `
 | Where-Object {($_.LastWriteTime -gt (Get-Date).AddDays(-1 * $logsFromDays))} `
 | ForEach-Object {
     $logFile = $_.FullName
     $logPrefixLength = $logPath.length
     $logZipPath = $logFile.Remove(0, $logPrefixLength)
     $logZipPath = $logZipPath.TrimStart("/")
	 $logZipPath = $logZipPath.TrimStart("\")
     Write-Host "  $($logZipPath)"
     [System.IO.Compression.ZipFileExtensions]::CreateEntryFromFile($zip, $logFile, $logZipPath, $compressionLevel) 1>$null
 }

$zip.Dispose()
Write-Host
Write-Host "Generated file: ${zipFileName}"
Set-Location -Path $PsScriptRoot